<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ToggleLayerVisibility</name>
    <message>
        <location filename="../ToggleLayerVisibilityInit.js" line="+2"/>
        <source>&amp;Toggle Visibility</source>
        <translation>&amp;Interruttore di visibilità</translation>
    </message>
</context>
</TS>
